@@ -1,8 +1,7 @@
 library(cluster)
 
 ## generate 1500 objects, divided into 2 clusters.
-if(R.version$major != "1" || as.numeric(R.version$minor) >= 7) RNGversion("1.6")
-set.seed(264)
+set.seed(144)
 x <- rbind(cbind(rnorm(700, 0,8), rnorm(700, 0,8)),
            cbind(rnorm(800,50,8), rnorm(800,10,8)))
 
@@ -21,8 +20,8 @@ stopifnot(identical(clara0$clustering, pam0$clustering)
 
 summary(clara2 <- clara(x, 2))
 
-clInd <- c("objective", "medoids", "clusinfo")
-clIn4 <- c(clInd, "sample")
+clInd <- c("objective", "i.med", "medoids", "clusinfo")
+clInS <- c(clInd, "sample")
 ## clara() {as original code} always draws the *same* random samples !!!!
 clara(x, 2, samples = 50)[clInd]
 for(i in 1:20)
@@ -33,8 +32,13 @@ clara(x, 2, samples = 149)[clInd]
 clara(x, 2, samples = 200)[clInd]
 ## Note that this last one is practically identical to the slower  pam() one
 
-x[print(sample(length(x), 20))] <- NA
-clara(x, 2, samples = 50)[clInd]
+(ii <- sample(length(x), 20))
+## This was bogous (and lead to seg.faults); now properly gives error.
+## but for these, now see  ./clara-NAs.R
+if(FALSE) { ##		   ~~~~~~~~~~~~~
+    x[ii] <- NA
+    try( clara(x, 2, samples = 50) )
+}
 
 ###-- Larger example: 2000 objects, divided into 5 clusters.
 x5 <- rbind(cbind(rnorm(400, 0,4), rnorm(400, 0,4)),
@@ -68,8 +72,6 @@ plot(clx3)
 
 ###--- End version of example(clara) -------
 
-
-
 ##  small example(s):
 data(ruspini)
 
@@ -84,21 +86,21 @@ daisy(ru5, "manhattan")
 ## Dissimilarities :  11 118 143 107 132  89
 
 ## no problem anymore, since 2002-12-28:
-clara(ru5, k=3, met="manhattan", sampsize=3,trace=2)[clIn4]
-clara(ru5, k=3, met="manhattan", sampsize=4,trace=1)[clIn4]
+clara(ru5, k=3, met="manhattan", sampsize=3,trace=2)[clInS]
+clara(ru5, k=3, met="manhattan", sampsize=4,trace=1)[clInS]
 
 daisy(ru4, "manhattan")
-## this one gives problem, from ss = 6 on ___ still after 2002-12-28 ___ :
+## this one (k=3) gives problem, from ss = 6 on ___ still after 2002-12-28 ___ :
 for(ss in 4:nrow(ru4)){
     cat("---\n\nsample size = ",ss,"\n")
-    print(clara(ru4,k=3,met="manhattan",sampsize=ss)[clIn4])
+    print(clara(ru4,k=3,met="manhattan",sampsize=ss)[clInS])
 }
 for(ss in 4:nrow(ru3)){
     cat("---\n\nsample size = ",ss,"\n")
-    print(clara(ru3,k=4,met="manhattan",sampsize=ss)[clIn4])
+    print(clara(ru3,k=4,met="manhattan",sampsize=ss)[clInS])
 }
 
 ## Last Line:
 cat('Time elapsed: ', proc.time() - .proctime00,'\n')
-## Lynne (P IV, 1.6 GHz): 18.81
+## Lynne (P IV, 1.6 GHz): 18.81; then (no NA; R 1.9.0-alpha): 15.07
 ## nb-mm (P III,700 MHz): 27.97
